@@ -11,9 +11,9 @@ class DefaultFormatter(logging.Formatter):
         elif(level <= logging.INFO):
             return termcolor.colored(" {:8s} ".format(levelname), "green")
         elif(level <= logging.WARNING):
-            return termcolor.colored(" {:8s} ".format(levelname), "black", "on_yellow")
+            return termcolor.colored(" {:8s} ".format(levelname), "green", "on_yellow")
         elif(level <= logging.ERROR):
-            return termcolor.colored(" {:8s} ".format(levelname), "black", "on_light_red")
+            return termcolor.colored(" {:8s} ".format(levelname), "green", "on_red")
         elif(level <= logging.CRITICAL):
             return termcolor.colored(" {:8s} ".format(levelname), "white", "on_red")
 
